@@ -10,7 +10,7 @@ def test_find_paragraphs_by_position():
         paras = client.find_paragraphs(None)
         assert len(paras) == 172
 
-        paras_page0 = client.find_paragraphs(Position.from_page_index(0))
+        paras_page0 = client.find_paragraphs(Position.at_page(0))
         assert len(paras_page0) == 2
 
         first = paras_page0[0]
@@ -29,8 +29,7 @@ def test_find_paragraphs_by_position():
 def test_find_paragraphs_by_text():
     base_url, token, pdf_path = _require_env_and_fixture('ObviouslyAwesome.pdf')
     with ClientV1(token=token, pdf_data=str(pdf_path), base_url=base_url, read_timeout=30.0) as client:
-        pos = Position.from_page_index(0)
-        pos.text_starts_with = 'The Complete'
+        pos = Position.at_page(0).with_text_starts('The Complete')
         paras = client.find_paragraphs(pos)
         assert len(paras) == 1
         p = paras[0]
@@ -43,22 +42,19 @@ def test_find_paragraphs_by_text():
 def test_delete_paragraph():
     base_url, token, pdf_path = _require_env_and_fixture('ObviouslyAwesome.pdf')
     with ClientV1(token=token, pdf_data=str(pdf_path), base_url=base_url, read_timeout=30.0) as client:
-        pos_del = Position.from_page_index(0)
-        pos_del.text_starts_with = 'The Complete'
+        pos_del = Position.at_page(0).with_text_starts('The Complete')
         ref = client.find_paragraphs(pos_del)[0]
         assert client.delete(ref) is True
-        pos_del2 = Position.from_page_index(0)
-        pos_del2.text_starts_with = 'The Complete'
+        pos_del2 = Position.at_page(0).with_text_starts('The Complete')
         assert client.find_paragraphs(pos_del2) == []
 
 
 def test_move_paragraph():
     base_url, token, pdf_path = _require_env_and_fixture('ObviouslyAwesome.pdf')
     with ClientV1(token=token, pdf_data=str(pdf_path), base_url=base_url, read_timeout=30.0) as client:
-        pos_move = Position.from_page_index(0)
-        pos_move.text_starts_with = 'The Complete'
+        pos_move = Position.at_page(0).with_text_starts('The Complete')
         ref = client.find_paragraphs(pos_move)[0]
-        new_pos = Position.on_page_coordinates(0, 0.1, 300)
+        new_pos = Position.at_page_coordinates(0, 0.1, 300)
         assert client.move(ref, new_pos) is True
         ref2 = client.find_paragraphs(new_pos)[0]
         assert ref2 is not None
@@ -66,8 +62,7 @@ def test_move_paragraph():
 
 def _assert_new_paragraph_exists(client: ClientV1):
     # Validate via find_text_lines for text starting with 'Awesomely'
-    pos = Position.from_page_index(0)
-    pos.text_starts_with = 'Awesomely'
+    pos = Position.at_page(0).with_text_starts('Awesomely')
     lines = client.find_text_lines(pos)
     assert len(lines) >= 1
 
@@ -75,14 +70,13 @@ def _assert_new_paragraph_exists(client: ClientV1):
 def test_modify_paragraph():
     base_url, token, pdf_path = _require_env_and_fixture('ObviouslyAwesome.pdf')
     with ClientV1(token=token, pdf_data=str(pdf_path), base_url=base_url, read_timeout=30.0) as client:
-        pos_mod = Position.from_page_index(0)
-        pos_mod.text_starts_with = 'The Complete'
+        pos_mod = Position.at_page(0).with_text_starts('The Complete')
         ref = client.find_paragraphs(pos_mod)[0]
         new_paragraph = client.paragraph_builder() \
             .from_string('Awesomely\nObvious!') \
             .with_font(Font('Helvetica', 14)) \
             .with_line_spacing(0.7) \
-            .with_position(Position.on_page_coordinates(0, 300.1, 500)) \
+            .with_position(Position.at_page_coordinates(0, 300.1, 500)) \
             .build()
         assert client.modify_paragraph(ref, new_paragraph) is True
         _assert_new_paragraph_exists(client)
@@ -91,8 +85,7 @@ def test_modify_paragraph():
 def test_modify_paragraph_simple():
     base_url, token, pdf_path = _require_env_and_fixture('ObviouslyAwesome.pdf')
     with ClientV1(token=token, pdf_data=str(pdf_path), base_url=base_url, read_timeout=30.0) as client:
-        pos_mod2 = Position.from_page_index(0)
-        pos_mod2.text_starts_with = 'The Complete'
+        pos_mod2 = Position.at_page(0).with_text_starts('The Complete')
         ref = client.find_paragraphs(pos_mod2)[0]
         assert client.modify_paragraph(ref, 'Awesomely\nObvious!') is True
         _assert_new_paragraph_exists(client)
@@ -105,7 +98,7 @@ def test_add_paragraph_with_custom_font1_expect_not_found():
             .from_string('Awesomely\nObvious!') \
             .with_font(Font('Roboto', 14)) \
             .with_line_spacing(0.7) \
-            .with_position(Position.on_page_coordinates(0, 300.1, 500))
+            .with_position(Position.at_page_coordinates(0, 300.1, 500))
         with pytest.raises(Exception) as excinfo:
             assert client.add_paragraph(pb.build()) is True
         assert 'Font not found' in str(excinfo.value)
@@ -118,7 +111,7 @@ def test_add_paragraph_with_custom_font1_1():
             .from_string('Awesomely\nObvious!') \
             .with_font(Font('Roboto-Regular', 14)) \
             .with_line_spacing(0.7) \
-            .with_position(Position.on_page_coordinates(0, 300.1, 500))
+            .with_position(Position.at_page_coordinates(0, 300.1, 500))
         assert client.add_paragraph(pb.build()) is True
         _assert_new_paragraph_exists(client)
 
@@ -134,7 +127,7 @@ def test_add_paragraph_with_custom_font1_2():
             .from_string('Awesomely\nObvious!') \
             .with_font(roboto) \
             .with_line_spacing(0.7) \
-            .with_position(Position.on_page_coordinates(0, 300.1, 500))
+            .with_position(Position.at_page_coordinates(0, 300.1, 500))
         assert client.add_paragraph(pb.build()) is True
         _assert_new_paragraph_exists(client)
 
@@ -150,7 +143,7 @@ def test_add_paragraph_with_custom_font2():
             .from_string('Awesomely\nObvious!') \
             .with_font(asimovian) \
             .with_line_spacing(0.7) \
-            .with_position(Position.on_page_coordinates(0, 300.1, 500))
+            .with_position(Position.at_page_coordinates(0, 300.1, 500))
         assert client.add_paragraph(pb.build()) is True
         _assert_new_paragraph_exists(client)
 
@@ -159,14 +152,14 @@ def test_add_paragraph_with_custom_font3():
     base_url, token, pdf_path = _require_env_and_fixture('ObviouslyAwesome.pdf')
     # Use DancingScript-Regular.ttf from repo fonts directory
     from pathlib import Path
-    repo_root = Path(__file__).resolve().parents[4]
-    ttf_path = repo_root / 'fonts' / 'DancingScript-Regular.ttf'
+    repo_root = Path(__file__).resolve().parents[2]
+    ttf_path = repo_root / 'tests/fixtures' / 'DancingScript-Regular.ttf'
     with ClientV1(token=token, pdf_data=str(pdf_path), base_url=base_url, read_timeout=30.0) as client:
         pb = client.paragraph_builder() \
             .from_string('Awesomely\nObvious!') \
             .with_font_file(str(ttf_path), 24) \
             .with_line_spacing(1.8) \
             .with_color(Color(0, 0, 255)) \
-            .with_position(Position.on_page_coordinates(0, 300.1, 500))
+            .with_position(Position.at_page_coordinates(0, 300.1, 500))
         assert client.add_paragraph(pb.build()) is True
         _assert_new_paragraph_exists(client)
